@@ -66,11 +66,11 @@ def align_and_median(infiles):
               for ind in shift_indices]
 
     # Warn for ghost images if realignment requires shifting by more than
-    # a quarter-field.
-    if (abs(max(deltas, key=lambda x: abs(x[0]))[0]) > nX / 4
-       or abs(max(deltas, key=lambda x: abs(x[1]))[1]) > nY / 4):
+    # 15% of the field size.
+    if (abs(max(deltas, key=lambda x: abs(x[0]))[0]) > nX * 0.15
+       or abs(max(deltas, key=lambda x: abs(x[1]))[1]) > nY * 0.15):
         pieces = basename(infiles[0]).split('_')
-        click.echo('W: In {}:{}:{}, shifting over a quarter-field. '
+        click.echo('W: In {}:{}:{}, shifting by more than 15% of the field. '
                    'Beware of ghosts!'.format(pieces[0], pieces[1], pieces[2]))
 
     # Roll the images to realign them and return their median.
@@ -173,7 +173,7 @@ def write_png(fname, plt):
     image = fits.getdata(fname)
     norm = ImageNormalize(image, ZScaleInterval())
     plt.figure(42)
-    plt.imshow(image, origin='lower', norm=norm, cmap='jet')
+    plt.imshow(image, norm=norm, cmap='jet')
     try:
         # If the zscale algorithm doesn't converge, an UnboundLocalError is
         # raised by astropy.visualization ...
@@ -184,7 +184,7 @@ def write_png(fname, plt):
         plt.clf()
         sample = np.random.choice(image.ravel(), 1000)
         norm = colors.Normalize(np.min(sample), np.max(sample), clip=True)
-        plt.imshow(image, origin='lower', norm=norm, cmap='jet')
+        plt.imshow(image, norm=norm, cmap='jet')
         plt.colorbar()
     plt.title(basename(fname).split(".fit")[0])
     plt.savefig('{}.png'.format(fname.split(".fit")[0]), bbox_inches='tight')
@@ -192,6 +192,7 @@ def write_png(fname, plt):
 
 
 @click.command()
+@click.version_option()
 @click.option('--setup', '-s', is_flag=True,
               help='Sets up the directory for reduction. Use this option only '
               'the first time astro_reduce is run in the directory.')
@@ -217,7 +218,7 @@ def cli(setup, interpolate, verbose, tmppng, redpng):
 
     '''
     # Initialize configuration file name and timer.
-    conf_file_name = '{}.json'.format(getcwd().split("/")[-1])
+    conf_file_name = '{}.json'.format(basename(getcwd()))
     t0 = time()
 
     # If setup option is on, set up the directory for reduction.
